<?php

namespace Drupal\vc_actions_volunteer\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Url;
use Drupal\vc_actions\Entity\VCAction;
use Drupal\vc_needs\Entity\VCNeed;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\Request;

/**
 * Class VCActionsVolunteerController
 * @package Drupal\vc_actions_volunteer\Controller
 */
class VCActionsVolunteerController extends ControllerBase {

  /**
   * Redirect to the previous page.
   */
  public function redirectToPrevious() {
    // Return to where we came from
    $server = Request::createFromGlobals()->server;
    $return = $server->get('HTTP_REFERER');
    $http = $server->get('HTTPS') ? 'https://' : 'http://';
    $domain = $http . $server->get('SERVER_NAME');
    $port = ':' . $server->get('SERVER_PORT');
    $return = str_replace($domain, '', $return);
    $return = str_replace($port, '', $return);
    $return = $return ? $return : '/';
    $url = Url::fromUserInput($return);

    $response = new RedirectResponse($url->toString());
//    $request = \Drupal::request();
//
//    // Save the session so things like messages get saved.
//    $request->getSession()->save();
//    $response->prepare($request);
//
//    // Make sure to trigger kernel events.
//    \Drupal::service('kernel')->terminate($request, $response);
//    $response->send();
    return $response;
  }

  /**
   * @param VCNeed $vc_need
   * @return RedirectResponse
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  public function volunteer(VCNeed $vc_need) {

    $volunteer = \Drupal::currentUser()->id();
    $volunteer_name = \Drupal::currentUser()->getDisplayName();
    $action_data = [
      'name' => t('%volunteer volunteering for %need', ['%volunteer' => $volunteer_name, '%need' => $vc_need->label()]),
      'type' => 'volunteer_action',
      'field_volunteer' => $volunteer,
      'field_need' => $vc_need->id()
    ];

    $action_data['name'] = strip_tags($action_data['name']->render());

    $action = VCAction::create($action_data);
    $action->save();

    return $this->redirectToPrevious();
  }

}
